
TODO_64_79_28_85: make `publish_package.bash` upgrade all packages before test

Use special directory `release_env` where `env_packages.txt` is captured.

Script `publish_package.bash` must ensure:
*   `conf` is configured to use `release_env` (can test it by running bootstrap with `dst/release_env`)
*   server and client config are symlinks to `sample_conf`
*   other files match template configs (hard to do at the moment as template configs are non-extractable embedded into bootstrap)

